About — species 0.1.2 documentation

# About

## Questions & feedback

species is developed by Tomas Stolker (tomas.stolker@phys.ethz.ch). Feel free to send an email for questions, comments, or suggestions.

## Attribution

Please cite Stolker et al. (2020) whenever results from species are used in a publication. Please also make sure to give credit the relevant papers regarding the use of the publicly available data that species is using, such as the photometric and spectral libraries, atmospheric models, evolutionary models, and photometry of individual objects. The species logo is available for use in presentations.